@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2008-2020 EDF R&D
+# Copyright (C) 2008-2021 EDF R&D
 #
 # This file is part of SALOME ADAO module
 #
@@ -55,9 +55,9 @@ class AdaoGenerator(PythonGenerator):
     ch.setFormatter(formatter)
     self.logger.addHandler(ch)
 
-  def gener(self,obj,format='brut',config=None,appli=None):
+  def gener(self,obj,format='brut',config=None,appliEficas=None):
     self.logger.debug("method gener called")
-    self.text_comm = PythonGenerator.gener(self, obj, format, config)
+    self.text_comm = PythonGenerator.gener(self, obj, format, config, appliEficas)
     for key, value in self.dictMCVal.items():
       self.logger.debug("dictMCVAl %s %s" % (key,value))
 
@@ -95,16 +95,23 @@ class AdaoGenerator(PythonGenerator):
 
   def generate_da(self):
 
-    if "__CHECKING_STUDY__StudyName" in self.dictMCVal.keys():
-      self.type_of_study = "CHECKING_STUDY"
-    else:
-      self.type_of_study = "ASSIMILATION_STUDY"
-
     self.text_da += "#-*- coding: utf-8 -*-\n"
     self.text_da += "study_config = {}\n"
 
     # Extraction de Study_type
-    self.text_da += "study_config['StudyType'] = '" + self.type_of_study + "'\n"
+    if "__CHECKING_STUDY__StudyName" in self.dictMCVal.keys():
+      self.type_of_study = "CHECKING_STUDY"
+      self.text_da += "study_config['StudyType'] = '\"CHECKING_STUDY\"'\n"
+    elif "__OPTIMIZATION_STUDY__StudyName" in self.dictMCVal.keys():
+      self.type_of_study = "OPTIMIZATION_STUDY"
+      self.text_da += "study_config['StudyType'] = '\"ASSIMILATION_STUDY\"'\n"
+    elif "__REDUCTION_STUDY__StudyName" in self.dictMCVal.keys():
+      self.type_of_study = "REDUCTION_STUDY"
+      self.text_da += "study_config['StudyType'] = '\"ASSIMILATION_STUDY\"'\n"
+    else:
+      self.type_of_study = "ASSIMILATION_STUDY"
+      self.text_da += "study_config['StudyType'] = '\"ASSIMILATION_STUDY\"'\n"
+
     # Extraction de StudyName
     self.text_da += "study_config['Name'] = '" + self.dictMCVal["__"+self.type_of_study+"__StudyName"] + "'\n"
     # Extraction de Debug
