@@ -1,6 +1,6 @@
 #-*-coding:utf-8-*-
 #
-# Copyright (C) 2008-2020 EDF R&D
+# Copyright (C) 2008-2021 EDF R&D
 #
 # This file is part of SALOME ADAO module
 #
@@ -35,7 +35,8 @@ import traceback
 import codecs
 
 # Pour disposer des classes dans l'espace de nommage lors du pickle
-from daCore.AssimilationStudy import AssimilationStudy
+from daCore.Aidsm import Aidsm
+from daCore.AssimilationStudy import AssimilationStudy # JPA à résorber
 from daYacsIntegration import daStudy
 
 def dumps( data ):
